"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const debug_1 = __importDefault(require("debug"));
const debug = debug_1.default("text-stream-search");
const delay_1 = __importDefault(require("delay"));
// calls the given handler exactly one time
// when text matches the given string
class BaseSubscription {
    constructor(accumulator, resolve, reject, timeout) {
        this.accumulator = accumulator;
        this.resolve = resolve;
        this.reject = reject;
        if (timeout != null) {
            setTimeout(this.onTimeout.bind(this), timeout);
        }
    }
    // checks for matches
    async check(text) {
        const match = this.matches(text);
        if (match) {
            await this.foundMatch(match);
        }
    }
    getDisplayName() {
        throw new Error("implement in subclass");
    }
    // called with the matching text when a match is found
    async foundMatch(text) {
        debug(`found match for ${this.getDisplayName()}`);
        await delay_1.default(1);
        this.resolve(text);
    }
    // Indicates whether the given text contains the pattern this subscription is looking for
    // by returning the matching text or null if there are no matches
    matches(_) {
        throw new Error("implement in subclass");
    }
    // called after a given timeout
    onTimeout() {
        const errorMessage = `Expected '${this.accumulator.toString()}' to include ${this.getDisplayName()}`;
        debug(`Timeout: rejecting with error message '${errorMessage}'`);
        this.reject(new Error(errorMessage));
    }
}
exports.default = BaseSubscription;
