"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const debug_1 = __importDefault(require("debug"));
const base_subscription_1 = __importDefault(require("./base-subscription"));
const debug = debug_1.default("text-stream-search:string-search");
// Calls the given handler exactly one time
// when text matches the given string
class StringSubscription extends base_subscription_1.default {
    constructor(query, accumulator, resolve, reject, timeout) {
        super(accumulator, resolve, reject, timeout);
        this.searchText = query;
    }
    // Returns the display name for debug / error messages
    getDisplayName() {
        return `string '${this.searchText}'`;
    }
    // Indicates whether the given text contains the string this subscription is looking for
    // by returning the matching text or null if there are no matches
    matches(text) {
        const found = text.includes(this.searchText);
        if (found) {
            debug(`search for '${this.searchText}' found a match in '${text}'`);
            return this.searchText;
        }
        else {
            debug(`no match in '${text}'`);
            return null;
        }
    }
}
exports.default = StringSubscription;
